from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool
from django.utils.translation import gettext_lazy as _

from .models import PDFEmbedModel

@plugin_pool.register_plugin
class PDFEmbedPlugin(CMSPluginBase):
    model = PDFEmbedModel
    name = "PDF Embed"
    render_template = "djangocms_pdfembed/pdf_embed.html"
    cache = False

    def render(self, context, instance, placeholder):
        context = super().render(context, instance, placeholder)
        return context


# Generated by Django 3.2 on 2023-01-13 15:25

from django.db import migrations, models
import django.db.models.deletion
import filer.fields.file


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('cms', '0022_auto_20180620_1551'),
        ('filer', '0015_alter_file_owner_alter_file_polymorphic_ctype_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='PDFEmbedModel',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='pdfembed_pdfembedmodel', serialize=False, to='cms.cmsplugin')),
                ('height', models.CharField(default='500px', max_length=10)),
                ('width', models.CharField(default='100%', max_length=10)),
                ('pdf', filer.fields.file.FilerFileField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='filer.file', verbose_name='PDF')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]



from cms.models.pluginmodel import CMSPlugin
from filer.fields.image import FilerFileField
from django.db import models

class PDFEmbedModel(CMSPlugin):
    height = models.CharField(max_length=10, default='500px')
    width = models.CharField(max_length=10, default='100%')
    pdf = FilerFileField(
        verbose_name='PDF',
        blank=True,
        null=True,
        on_delete=models.SET_NULL,
        related_name='+',
    )

    @property
    def pdf_src(self):
        # picture can be empty, for example when the image is removed from filer
        # in this case we want to return an empty string to avoid #69
        if not self.pdf:
            return ''
        # return the original, unmodified picture
        else:
            return self.pdf.url